Index: trunk/MagicSoft/Mars/manalysis/MMultiDimDistCalc.cc
===================================================================
--- trunk/MagicSoft/Mars/manalysis/MMultiDimDistCalc.cc	(revision 8074)
+++ trunk/MagicSoft/Mars/manalysis/MMultiDimDistCalc.cc	(revision 8075)
@@ -55,5 +55,5 @@
 
 #include "MParList.h"
-#include "MDataChain.h"
+//#include "MDataPhrase.h"
 #include "MDataArray.h"
 
@@ -125,5 +125,5 @@
     while ((data=Next()))
     {
-        MDataChain *chain = new MDataChain(data->GetName());
+        MDataPhrase *chain = new MDataPhrase(data->GetName());
         if (!chain->PreProcess(plist))
         {
Index: trunk/MagicSoft/Mars/mhbase/MHMatrix.cc
===================================================================
--- trunk/MagicSoft/Mars/mhbase/MHMatrix.cc	(revision 8074)
+++ trunk/MagicSoft/Mars/mhbase/MHMatrix.cc	(revision 8075)
@@ -148,5 +148,5 @@
 // Add a new column to the matrix. This can only be done before the first
 // event (row) was filled into the matrix. For the syntax of the rule
-// see MDataChain.
+// see MDataPhrase.
 // Returns the index of the new column, -1 in case of failure.
 // (0, 1, 2, ... for the 1st, 2nd, 3rd, ...)

Index: trunk/MagicSoft/Mars/mfileio/MWriteAsciiFile.cc
===================================================================
--- trunk/MagicSoft/Mars/mfileio/MWriteAsciiFile.cc	(revision 8074)
+++ trunk/MagicSoft/Mars/mfileio/MWriteAsciiFile.cc	(revision 8075)
@@ -54,5 +54,5 @@
 
 #include "MDataList.h"   // MDataList
-#include "MDataChain.h"  // MDataChain
+#include "MDataPhrase.h" // MDataPhrase
 #include "MDataValue.h"  // MDataValue
 #include "MDataMember.h" // MDataMember
@@ -247,5 +247,5 @@
 //
 // Add a rule to be written as a column to the ascii file.
 // For more information about rules see MDataChain.
 //
 //  eg: MWriteAsciiFile::AddColumn("log10(MHillas.fEnergy)/2")
@@ -253,5 +253,5 @@
 void MWriteAsciiFile::AddColumn(const TString rule)
 {
-    MDataChain *chain = new MDataChain(rule);
+    MDataPhrase *chain = new MDataPhrase(rule);
     fList.Add(chain);
 }
@@ -247,5 +247,5 @@
 //
 // Add a rule to be written as a column to the ascii file.
-// For more information about rules see MDataChain.
+// For more information about rules see MDataPhrase.
 //
 //  eg: MWriteAsciiFile::AddColumn("log10(MHillas.fEnergy)/2")